RewriteError

Enum RewriteError 

pub enum RewriteError {
    BadAtom(String),
}
Error returned by rewrite_atoms when an atom does not match the expected c<digits> shape.

Variants



BadAtom(String)

An atom was not of the form c<digits>. kermit currently only supports constants encoded as dictionary IDs using this convention.